@@ -1,11 +1,16 @@
-from geoalchemy2 import functions as geo_func
-from sqlalchemy import func
-from sqlalchemy.orm import aliased, Query
-
-from threedi_modelchecker.checks import patterns
-from .base import BaseCheck
 from ..threedi_model import constants
 from ..threedi_model import models
+from .base import BaseCheck
+from geoalchemy2 import functions as geo_func
+from sqlalchemy import func
+from sqlalchemy import or_
+from sqlalchemy import text
+from sqlalchemy.orm import aliased
+from sqlalchemy.orm import Query
+from sqlalchemy.orm import Session
+from threedi_modelchecker.checks import patterns
+from typing import List
+from typing import NamedTuple
 
 
 class BankLevelCheck(BaseCheck):
@@ -31,8 +36,10 @@ class BankLevelCheck(BaseCheck):
         return q.all()
 
     def description(self):
-        return "CrossSectionLoaction.Banklevel cannot be null when calculation_type " \
-               "is CONNECTED or DOUBLE_CONNECTED"
+        return (
+            "CrossSectionLoaction.Banklevel cannot be null when calculation_type "
+            "is CONNECTED or DOUBLE_CONNECTED"
+        )
 
 
 class CrossSectionShapeCheck(BaseCheck):
@@ -254,26 +261,167 @@ class ConnectionNodesLength(BaseCheck):
     def get_invalid(self, session):
         start_node = aliased(models.ConnectionNode)
         end_node = aliased(models.ConnectionNode)
-        q = Query(
-            self.column.class_
-        ).join(
-            start_node, self.start_node
-        ).join(
-            end_node, self.end_node
-        ).filter(
-            geo_func.ST_Distance(
-                geo_func.ST_Transform(
-                    start_node.the_geom,
-                    Query(models.GlobalSetting.epsg_code).limit(1).label('epsg_code')
-                ),
-                geo_func.ST_Transform(
-                    end_node.the_geom,
-                    Query(models.GlobalSetting.epsg_code).limit(1).label('epsg_code')
+        q = (
+            Query(self.column.class_)
+            .join(start_node, self.start_node)
+            .join(end_node, self.end_node)
+            .filter(
+                geo_func.ST_Distance(
+                    geo_func.ST_Transform(
+                        start_node.the_geom,
+                        Query(models.GlobalSetting.epsg_code)
+                        .limit(1)
+                        .label("epsg_code"),
+                    ),
+                    geo_func.ST_Transform(
+                        end_node.the_geom,
+                        Query(models.GlobalSetting.epsg_code)
+                        .limit(1)
+                        .label("epsg_code"),
+                    ),
                 )
-            ) < self.min_distance
+                < self.min_distance
+            )
         )
         return list(q.with_session(session).all())
 
     def description(self) -> str:
-        return f"The distance of start- and end connectionnode of {self.table} is " \
-               f"too short, should be at least {self.min_distance} meters"
+        return (
+            f"The distance of start- and end connectionnode of {self.table} is "
+            f"too short, should be at least {self.min_distance} meters"
+        )
+
+
+class ConnectionNodesDistance(BaseCheck):
+    """Check that the distance between CONNECTED connection nodes is above a certain
+    threshold
+    """
+
+    def __init__(self, minimum_distance: float, *args, **kwargs):
+        """
+        :param minimum_distance: threshold distance in meters
+        """
+        super().__init__(column=models.ConnectionNode.id, *args, **kwargs)
+        self.minimum_distance = minimum_distance
+
+    def get_invalid(self, session: Session) -> List[NamedTuple]:
+        """
+        The query makes use of the SpatialIndex so we won't have to calculate the
+        distance between all connection nodes.
+
+        The query only works on a spatialite and therefore skips postgres.
+        """
+        if session.bind.name == "postgresql":
+            return []
+
+        check_spatial_index = (
+            "SELECT CheckSpatialIndex('v2_connection_nodes', 'the_geom')"
+        )
+        if not session.connection().execute(check_spatial_index).scalar():
+            recover_spatial_index = (
+                "SELECT RecoverSpatialIndex('v2_connection_nodes', 'the_geom')"
+            )
+            session.connection().execute(recover_spatial_index).scalar()
+
+        query = text(
+            """SELECT *
+               FROM v2_connection_nodes AS cn1, v2_connection_nodes AS cn2
+               WHERE
+                   distance(cn1.the_geom, cn2.the_geom, 1) < :min_distance
+                   AND cn1.ROWID != cn2.ROWID
+                   AND cn2.ROWID IN (
+                     SELECT ROWID
+                     FROM SpatialIndex
+                     WHERE (
+                       f_table_name = "v2_connection_nodes"
+                       AND search_frame = Buffer(cn1.the_geom, 0.0005)));
+            """
+        )
+        results = (
+            session.connection()
+            .execute(query, min_distance=self.minimum_distance)
+            .fetchall()
+        )
+
+        return results
+
+    def description(self) -> str:
+        return (
+            f"The connection_node is within {self.minimum_distance} meters of "
+            f"another connection_node."
+        )
+
+
+class OpenChannelsWithNestedNewton(BaseCheck):
+    """Checks whether the model has any open cross-section in use when the
+    NumericalSettings.use_of_nested_newton is turned off.
+
+    See https://github.com/nens/threeditoolbox/issues/522
+    """
+
+    def __init__(self):
+        super().__init__(column=models.Channel.id)
+
+    def get_invalid(self, session: Session) -> List[NamedTuple]:
+        invalid_channels = []
+
+        # Circle and egg cross-section definitions are always open:
+        circle_egg_definitions = (
+            Query(models.Channel)
+            .join(models.CrossSectionLocation, models.Channel.cross_section_locations)
+            .join(models.CrossSectionDefinition, models.CrossSectionLocation.definition)
+            .filter(
+                models.NumericalSettings.use_of_nested_newton == 0,
+                or_(
+                    models.CrossSectionDefinition.shape.in_(
+                        [
+                            constants.CrossSectionShape.CIRCLE,
+                            constants.CrossSectionShape.EGG,
+                        ]
+                    )
+                ),
+            )
+        )
+        invalid_channels += circle_egg_definitions.with_session(session).all()
+
+        # Tabulated cross-section definitions are open when the last element of 'width'
+        # is zero
+        open_definitions = (
+            Query(
+                [
+                    models.Channel,
+                    models.CrossSectionLocation,
+                    models.CrossSectionDefinition,
+                ]
+            )
+            .join(models.CrossSectionLocation, models.Channel.cross_section_locations)
+            .join(models.CrossSectionDefinition, models.CrossSectionLocation.definition)
+            .filter(
+                models.NumericalSettings.use_of_nested_newton == 0,
+                models.CrossSectionDefinition.shape.in_(
+                    [
+                        constants.CrossSectionShape.TABULATED_RECTANGLE,
+                        constants.CrossSectionShape.TABULATED_TRAPEZIUM,
+                    ]
+                ),
+            )
+        )
+        for channel, _, definition in open_definitions.with_session(session).all():
+            try:
+                if definition.width.split(" ")[-1] in ("0", "0.", "0.0"):
+                    # Open channel
+                    invalid_channels.append(channel)
+            except Exception:
+                # Many things can go wrong, I won't bother with trying to catch all
+                # possible exceptions
+                pass
+        return invalid_channels
+
+    def description(self) -> str:
+        return (
+            "Channel in the model with an open cross-section-definition while also "
+            "having the NumericalSettings.use_of_nested_newton turned off can be a "
+            "cause of instabilities in the simulation. Please turn on the "
+            "NumericalSettings.use_of_nested_newton on or make the Channel a "
+            "closed definition."
+        )
