@@ -1,15 +1,12 @@
-from typing import List
-
-from geoalchemy2 import functions as geo_func
-from sqlalchemy import Integer, func
-from sqlalchemy import and_
-from sqlalchemy import cast
-from sqlalchemy import or_
-from sqlalchemy.orm import Query
-
-from .checks.base import QueryCheck, ForeignKeyCheck, UniqueCheck, \
-    TypeCheck, GeometryCheck, GeometryTypeCheck, EnumCheck, BaseCheck
+from .checks.base import BaseCheck
+from .checks.base import EnumCheck
+from .checks.base import ForeignKeyCheck
 from .checks.base import GeneralCheck
+from .checks.base import GeometryCheck
+from .checks.base import GeometryTypeCheck
+from .checks.base import QueryCheck
+from .checks.base import TypeCheck
+from .checks.base import UniqueCheck
 from .checks.factories import generate_enum_checks
 from .checks.factories import generate_foreign_key_checks
 from .checks.factories import generate_geometry_checks
@@ -17,11 +14,24 @@ from .checks.factories import generate_geometry_type_checks
 from .checks.factories import generate_not_null_checks
 from .checks.factories import generate_type_checks
 from .checks.factories import generate_unique_checks
-from .checks.other import BankLevelCheck, CrossSectionShapeCheck, ConnectionNodesLength
+from .checks.other import BankLevelCheck
+from .checks.other import ConnectionNodesDistance
+from .checks.other import ConnectionNodesLength
+from .checks.other import CrossSectionShapeCheck
+from .checks.other import OpenChannelsWithNestedNewton
 from .checks.other import TimeseriesCheck
 from .checks.other import Use0DFlowCheck
 from .threedi_model import models
 from .threedi_model.models import constants
+from geoalchemy2 import functions as geo_func
+from sqlalchemy import and_
+from sqlalchemy import cast
+from sqlalchemy import func
+from sqlalchemy import Integer
+from sqlalchemy import or_
+from sqlalchemy.orm import Query
+from typing import List
+
 
 FOREIGN_KEY_CHECKS: List[ForeignKeyCheck] = []
 UNIQUE_CHECKS: List[UniqueCheck] = []
@@ -178,11 +188,11 @@ RANGE_CHECKS: List[BaseCheck] = [
     ),
     GeneralCheck(
         column=models.GlobalSetting.maximum_sim_time_step,
-        criterion_valid=models.GlobalSetting.maximum_sim_time_step >= models.GlobalSetting.sim_time_step,  # noqa: E501
+        criterion_valid=models.GlobalSetting.maximum_sim_time_step >= models.GlobalSetting.sim_time_step,
     ),
     GeneralCheck(
         column=models.GlobalSetting.sim_time_step,
-        criterion_valid=models.GlobalSetting.sim_time_step >= models.GlobalSetting.minimum_sim_time_step,  # noqa: E501
+        criterion_valid=models.GlobalSetting.sim_time_step >= models.GlobalSetting.minimum_sim_time_step,
     ),
 ]
 
@@ -193,8 +203,8 @@ OTHER_CHECKS: List[BaseCheck] = [
     GeneralCheck(
         column=models.BoundaryCondition1D.connection_node_id,
         criterion_invalid=or_(
-            models.BoundaryCondition1D.connection_node_id == models.Pumpstation.connection_node_start_id,  # noqa: E501
-            models.BoundaryCondition1D.connection_node_id == models.Pumpstation.connection_node_end_id,  # noqa: E501
+            models.BoundaryCondition1D.connection_node_id == models.Pumpstation.connection_node_start_id,
+            models.BoundaryCondition1D.connection_node_id == models.Pumpstation.connection_node_end_id,
         )
     ),
     GeneralCheck(
@@ -202,7 +212,9 @@ OTHER_CHECKS: List[BaseCheck] = [
         criterion_valid=cast(models.GlobalSetting.output_time_step, Integer)
         % cast(models.GlobalSetting.sim_time_step, Integer) == 0
     ),
-    Use0DFlowCheck()
+    Use0DFlowCheck(),
+    OpenChannelsWithNestedNewton(),
+    ConnectionNodesDistance(minimum_distance=0.01),
 ]
 
 
@@ -214,14 +226,14 @@ CONDITIONAL_CHECKS = [
         ).filter(
             models.ConnectionNode.storage_area <= 0
         ),
-        message="The ConnectionNode.storage_area > 0 "
+        message="WARNING: The ConnectionNode.storage_area > 0 "
                 "when the ConnectionNode is a Manhole"
     ),
     QueryCheck(
         column=models.CrossSectionLocation.reference_level,
         invalid=Query(models.CrossSectionLocation).filter(
             models.CrossSectionLocation.bank_level != None,
-            models.CrossSectionLocation.reference_level >= models.CrossSectionLocation.bank_level  # noqa: E501
+            models.CrossSectionLocation.reference_level >= models.CrossSectionLocation.bank_level
         ),
         message="CrossSectionLocation.reference_level < CrossSectionLocation.bank_level"
                 "when CrossSectionLocation.bank_level is not null"
@@ -341,7 +353,7 @@ CONDITIONAL_CHECKS = [
             models.Interflow.interflow_type != constants.InterflowType.NO_INTERLFOW
         ),
         message=f"Interflow.impervious_layer_elevation cannot be null when "
-                f"Interflow.interflow_type is not {constants.InterflowType.NO_INTERLFOW}"  # noqa: E501
+                f"Interflow.interflow_type is not {constants.InterflowType.NO_INTERLFOW}"
     ),
     QueryCheck(
         column=models.Interflow.hydraulic_conductivity,
@@ -380,7 +392,7 @@ CONDITIONAL_CHECKS = [
         ).join(
             models.Manhole
         ).filter(
-            models.Pumpstation.lower_stop_level >= models.Manhole.bottom_level,
+            models.Pumpstation.lower_stop_level <= models.Manhole.bottom_level,
         ),
         message="Pumpstation.lower_stop_level should be higher than "
                 "Manhole.bottom_level"
@@ -393,7 +405,7 @@ CONDITIONAL_CHECKS = [
         ).join(
             models.Manhole
         ).filter(
-            models.Pumpstation.lower_stop_level >= models.Manhole.bottom_level,
+            models.Pumpstation.lower_stop_level <= models.Manhole.bottom_level,
         ),
         message="Pumpstation.lower_stop_level should be higher than "
                 "Manhole.bottom_level"
@@ -419,7 +431,7 @@ CONDITIONAL_CHECKS = [
         ).join(
             models.Manhole
         ).filter(
-            models.Pipe.invert_level_start_point < models.Manhole.bottom_level,  # noqa: E501
+            models.Pipe.invert_level_start_point < models.Manhole.bottom_level,
         ),
         message="Pipe.invert_level_start_point should be higher than or equal to "
                 "Manhole.bottom_level"
@@ -520,6 +532,92 @@ CONDITIONAL_CHECKS = [
         end_node=models.Orifice.connection_node_end,
         min_distance=0.05
     ),
+    QueryCheck(
+        column=models.ConnectionNode.id,
+        invalid=Query(models.ConnectionNode).filter(
+            models.ConnectionNode.id.notin_(
+                Query(models.Manhole.connection_node_id).union_all(
+                    Query(models.Pipe.connection_node_start_id),
+                    Query(models.Pipe.connection_node_end_id),
+                    Query(models.Channel.connection_node_start_id),
+                    Query(models.Channel.connection_node_end_id),
+                    Query(models.Culvert.connection_node_start_id),
+                    Query(models.Culvert.connection_node_end_id),
+                    Query(models.Weir.connection_node_start_id),
+                    Query(models.Weir.connection_node_end_id),
+                    Query(models.Pumpstation.connection_node_start_id),
+                    Query(models.Pumpstation.connection_node_end_id),
+                    Query(models.Orifice.connection_node_start_id),
+                    Query(models.Orifice.connection_node_end_id)
+                )
+            )
+        ),
+        message="ConnectionNode should be connected to either a manhole, pipe, "
+                "channel, culvert, weir, pumpstation or orifice"
+    ),
+    QueryCheck(
+        column=models.Pipe.id,
+        invalid=Query(models.Pipe).join(
+            models.ConnectionNode,
+            models.Pipe.connection_node_start_id == models.ConnectionNode.id
+        ).filter(
+            models.Pipe.calculation_type == constants.PipeCalculationType.ISOLATED,
+            models.ConnectionNode.storage_area.is_(None)
+        ).union(
+            Query(models.Pipe).join(
+                models.ConnectionNode,
+                models.Pipe.connection_node_end_id == models.ConnectionNode.id
+            ).filter(
+                models.Pipe.calculation_type == constants.PipeCalculationType.ISOLATED,
+                models.ConnectionNode.storage_area.is_(None)
+            )
+        ),
+        message="Storage area of a isolated pipe cannot be null"
+    ),
+    QueryCheck(
+        column=models.NumericalSettings.convergence_eps,
+        invalid=Query(models.NumericalSettings).filter(
+            models.NumericalSettings.convergence_eps <= 0
+        ),
+        message="NumericalSettings.convergence_eps must be larger than 0"
+    ),
+    QueryCheck(
+        column=models.NumericalSettings.convergence_cg,
+        invalid=Query(models.NumericalSettings).filter(
+            models.NumericalSettings.convergence_cg <= 0
+        ),
+        message="NumericalSettings.convergence_cg must be larger than 0"
+    ),
+    QueryCheck(
+        column=models.NumericalSettings.general_numerical_threshold,
+        invalid=Query(models.NumericalSettings).filter(
+            models.NumericalSettings.general_numerical_threshold <= 0
+        ),
+        message="NumericalSettings.general_numerical_threshold must be larger than 0"
+    ),
+    QueryCheck(
+        column=models.NumericalSettings.flow_direction_threshold,
+        invalid=Query(models.NumericalSettings).filter(
+            models.NumericalSettings.flow_direction_threshold <= 0
+        ),
+        message="NumericalSettings.flow_direction_threshold must be larger than 0"
+    ),
+    QueryCheck(
+        column=models.NumericalSettings.use_of_nested_newton,
+        invalid=Query(models.NumericalSettings).filter(
+            models.NumericalSettings.use_of_nested_newton == 0,
+            or_(
+                Query(func.count(models.Pipe.id) > 0).label("pipes"),
+                Query(func.count(models.Culvert.id) > 0).label("culverts"),
+                Query(func.count(models.Orifice.id) > 0).label("orifices")
+            )
+        ),
+        message="NumericalSettings.use_of_nested_newton is turned off, this in "
+                "combination with pipes, culverts or orifices in the model can cause "
+                "instabilities in the simulation. Please reconsider turning on "
+                "NumericalSettings.use_of_nested_newton or removing the pipes, "
+                "culverts and orifices."
+    ),
 ]
 
 
@@ -549,7 +647,7 @@ class Config:
             NOT_NULL_CHECKS += generate_not_null_checks(model.__table__)
             INVALID_TYPE_CHECKS += generate_type_checks(model.__table__)
             INVALID_GEOMETRY_CHECKS += generate_geometry_checks(model.__table__)
-            INVALID_GEOMETRY_TYPE_CHECKS += generate_geometry_type_checks(model.__table__)  # noqa: E501
+            INVALID_GEOMETRY_TYPE_CHECKS += generate_geometry_type_checks(model.__table__)
             INVALID_ENUM_CHECKS += generate_enum_checks(model.__table__)
 
         self.checks += FOREIGN_KEY_CHECKS
