@@ -1,9 +1,12 @@
 from enum import Enum
 
-LATEST_MIGRATION_ID = 173
-LATEST_MIGRATION_NAME = (
-    "0171_auto__chg_field_v2aggregationsettings_aggregation_method__del_field_v2"
-)  # noqa
+
+LATEST_SOUTH_MIGRATION_ID = 174
+#  Migration 174 deletes some fields, which were already not present in the
+#  models of the threedi-modelchecker. Therefore we can both accept migration
+#  173 and 174.
+MIN_SCHEMA_VERSION = 173
+VERSION_TABLE_NAME = "schema_version"
 
 
 class BoundaryType(Enum):
