@@ -1,19 +1,17 @@
-from sqlalchemy import (
-    Boolean,
-    Column,
-    DateTime,
-    Float,
-    ForeignKey,
-    Integer,
-    String,
-    Text,
-)
+from . import constants
+from .custom_types import IntegerEnum
+from .custom_types import VarcharEnum
+from geoalchemy2.types import Geometry
+from sqlalchemy import Boolean
+from sqlalchemy import Column
+from sqlalchemy import Float
+from sqlalchemy import ForeignKey
+from sqlalchemy import Integer
+from sqlalchemy import String
+from sqlalchemy import Text
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import relationship
-from geoalchemy2.types import Geometry
 
-from .custom_types import IntegerEnum, VarcharEnum
-from . import constants
 
 Base = declarative_base()  # automap_base()
 
@@ -23,7 +21,10 @@ class Lateral2D(Base):
     id = Column(Integer, primary_key=True)
 
     type = Column(IntegerEnum(constants.Later2dType), nullable=False)
-    the_geom = Column(Geometry(geometry_type="POINT", srid=4326, spatial_index=True))
+    the_geom = Column(
+        Geometry(geometry_type="POINT", srid=4326, spatial_index=True, management=True),
+        nullable=False,
+    )
     timeseries = Column(Text, nullable=False)
 
 
@@ -35,7 +36,10 @@ class BoundaryConditions2D(Base):
     timeseries = Column(Text, nullable=False)
     boundary_type = Column(IntegerEnum(constants.BoundaryType), nullable=False)
     the_geom = Column(
-        Geometry(geometry_type="LINESTRING", srid=4326, spatial_index=True)
+        Geometry(
+            geometry_type="LINESTRING", srid=4326, spatial_index=True, management=True
+        ),
+        nullable=False,
     )
 
 
@@ -47,7 +51,8 @@ class CalculationPoint(Base):
     user_ref = Column(String(80), nullable=False)
     calc_type = Column(Integer, nullable=False)
     the_geom = Column(
-        Geometry(geometry_type="POINT", srid=4326, spatial_index=True), nullable=False
+        Geometry(geometry_type="POINT", srid=4326, spatial_index=True, management=True),
+        nullable=False,
     )
 
 
@@ -153,7 +158,9 @@ class Floodfill(Base):
     __tablename__ = "v2_floodfill"
     id = Column(Integer, primary_key=True)
     waterlevel = Column(Float)
-    the_geom = Column(Geometry(geometry_type="POINT", srid=4326, spatial_index=True))
+    the_geom = Column(
+        Geometry(geometry_type="POINT", srid=4326, spatial_index=True, management=True)
+    )
 
 
 class Interflow(Base):
@@ -175,7 +182,10 @@ class PumpedDrainageArea(Base):
     name = Column(String(64), nullable=False)
     code = Column(String(100), nullable=False)
     the_geom = Column(
-        Geometry(geometry_type="POLYGON", srid=4326, spatial_index=True), nullable=False
+        Geometry(
+            geometry_type="POLYGON", srid=4326, spatial_index=True, management=True
+        ),
+        nullable=False,
     )
 
 
@@ -216,7 +226,12 @@ class Surface(Base):
     surface_parameters_id = Column(
         Integer, ForeignKey(SurfaceParameter.__tablename__ + ".id"), nullable=False
     )
-    the_geom = Column(Geometry(geometry_type="POLYGON", srid=4326, spatial_index=True))
+    the_geom = Column(
+        Geometry(
+            geometry_type="POLYGON", srid=4326, spatial_index=True, management=True
+        ),
+        nullable=False,
+    )
 
 
 class GroundWater(Base):
@@ -259,7 +274,10 @@ class GridRefinement(Base):
     display_name = Column(String(255), nullable=False)
     refinement_level = Column(Integer, nullable=False)
     the_geom = Column(
-        Geometry(geometry_type="LINESTRING", srid=4326, spatial_index=True)
+        Geometry(
+            geometry_type="LINESTRING", srid=4326, spatial_index=True, management=True
+        ),
+        nullable=False,
     )
     code = Column(String(100), nullable=False)
 
@@ -270,7 +288,11 @@ class GridRefinementArea(Base):
     display_name = Column(String(255), nullable=False)
     refinement_level = Column(Integer, nullable=False)
     code = Column(String(100), nullable=False)
-    the_geom = Column(Geometry(geometry_type="POLYGON", srid=4326, spatial_index=True))
+    the_geom = Column(
+        Geometry(
+            geometry_type="POLYGON", srid=4326, spatial_index=True, management=True
+        )
+    )
 
 
 class CrossSectionDefinition(Base):
@@ -288,10 +310,13 @@ class ConnectionNode(Base):
     storage_area = Column(Float)
     initial_waterlevel = Column(Float)
     the_geom = Column(
-        Geometry(geometry_type="POINT", srid=4326, spatial_index=True), nullable=False
+        Geometry(geometry_type="POINT", srid=4326, spatial_index=True, management=True),
+        nullable=False,
     )
     the_geom_linestring = Column(
-        Geometry(geometry_type="LINESTRING", srid=4326, spatial_index=False)
+        Geometry(
+            geometry_type="LINESTRING", srid=4326, spatial_index=False, management=True
+        )
     )
     code = Column(String(100), nullable=False)
 
@@ -478,7 +503,9 @@ class Channel(Base):
     dist_calc_points = Column(Float)
     zoom_category = Column(IntegerEnum(constants.ZoomCategories))
     the_geom = Column(
-        Geometry(geometry_type="LINESTRING", srid=4326, spatial_index=True),
+        Geometry(
+            geometry_type="LINESTRING", srid=4326, spatial_index=True, management=True
+        ),
         nullable=False,
     )
 
@@ -510,7 +537,9 @@ class Windshielding(Base):
     southwest = Column(Float)
     west = Column(Float)
     northwest = Column(Float)
-    the_geom = Column(Geometry(geometry_type="POINT", srid=4326, spatial_index=True))
+    the_geom = Column(
+        Geometry(geometry_type="POINT", srid=4326, spatial_index=True, management=True)
+    )
     channel_id = Column(
         Integer, ForeignKey(Channel.__tablename__ + ".id"), nullable=False
     )
@@ -524,7 +553,10 @@ class CrossSectionLocation(Base):
     friction_type = Column(IntegerEnum(constants.FrictionType), nullable=False)
     friction_value = Column(Float, nullable=False)
     bank_level = Column(Float)
-    the_geom = Column(Geometry(geometry_type="POINT", srid=4326, spatial_index=True))
+    the_geom = Column(
+        Geometry(geometry_type="POINT", srid=4326, spatial_index=True, management=True),
+        nullable=False,
+    )
     channel_id = Column(
         Integer, ForeignKey(Channel.__tablename__ + ".id"), nullable=False
     )
@@ -591,7 +623,9 @@ class Culvert(Base):
     invert_level_start_point = Column(Float, nullable=False)
     invert_level_end_point = Column(Float, nullable=False)
     the_geom = Column(
-        Geometry(geometry_type="LINESTRING", srid=4326, spatial_index=True),
+        Geometry(
+            geometry_type="LINESTRING", srid=4326, spatial_index=True, management=True
+        ),
         nullable=False,
     )
 
@@ -618,7 +652,11 @@ class Culvert(Base):
 class DemAverageArea(Base):
     __tablename__ = "v2_dem_average_area"
     id = Column(Integer, primary_key=True)
-    the_geom = Column(Geometry(geometry_type="POLYGON", srid=4326, spatial_index=True))
+    the_geom = Column(
+        Geometry(
+            geometry_type="POLYGON", srid=4326, spatial_index=True, management=True
+        )
+    )
 
 
 class Weir(Base):
@@ -698,7 +736,9 @@ class Pumpstation(Base):
     zoom_category = Column(IntegerEnum(constants.ZoomCategories))
     classification = Column(Integer)
     sewerage = Column(Boolean, nullable=False)
-    type_ = Column(IntegerEnum(constants.PumpType), name="type", nullable=False)  # type: ignore[call-overload] # noqa
+    type_ = Column(
+        IntegerEnum(constants.PumpType), name="type", key="type_", nullable=False
+    )  # type: ignore[call-overload]
     start_level = Column(Float, nullable=False)
     lower_stop_level = Column(Float, nullable=False)
     upper_stop_level = Column(Float)
@@ -723,7 +763,10 @@ class Obstacle(Base):
     code = Column(String(100), nullable=False)
     crest_level = Column(Float, nullable=False)
     the_geom = Column(
-        Geometry(geometry_type="LINESTRING", srid=4326, spatial_index=True)
+        Geometry(
+            geometry_type="LINESTRING", srid=4326, spatial_index=True, management=True
+        ),
+        nullable=False,
     )
 
 
@@ -733,8 +776,10 @@ class Levee(Base):
     code = Column(String(100), default="", nullable=False)
     crest_level = Column(Float)
     the_geom = Column(
-        Geometry(geometry_type="LINESTRING", srid=4326, spatial_index=True),
-        nullable=False
+        Geometry(
+            geometry_type="LINESTRING", srid=4326, spatial_index=True, management=True
+        ),
+        nullable=False,
     )
     material = Column(IntegerEnum(constants.Material))
     max_breach_depth = Column(Float)
@@ -751,7 +796,8 @@ class ConnectedPoint(Base):
 
     exchange_level = Column(Float)
     the_geom = Column(
-        Geometry(geometry_type="POINT", srid=4326, spatial_index=True), nullable=False
+        Geometry(geometry_type="POINT", srid=4326, spatial_index=True, management=True),
+        nullable=False,
     )
 
 
@@ -769,7 +815,12 @@ class ImperviousSurface(Base):
     nr_of_inhabitants = Column(Float)
     area = Column(Float)
     dry_weather_flow = Column(Float)
-    the_geom = Column(Geometry(geometry_type="POLYGON", srid=4326, spatial_index=True))
+    the_geom = Column(
+        Geometry(
+            geometry_type="POLYGON", srid=4326, spatial_index=True, management=True
+        ),
+        nullable=False,
+    )
     impervious_surface_maps = relationship(
         "ImperviousSurfaceMap", back_populates="impervious_surface"
     )
@@ -793,14 +844,6 @@ class ImperviousSurfaceMap(Base):
     )
 
 
-class SouthMigrationHistory(Base):
-    __tablename__ = "south_migrationhistory"
-    id = Column(Integer, primary_key=True)
-    app_name = Column(String(255), nullable=False)
-    migration = Column(String(255), nullable=False)
-    applied = Column(DateTime, nullable=False)
-
-
 DECLARED_MODELS = [
     AggregationSettings,
     BoundaryCondition1D,
